@@ -4,7 +4,7 @@ sys.path.append('../')
 import ctypes
 from ctypes import *
 from algorithmLib.formatConvert.wav_pcm import pcm2wav
-from algorithmLib.Function import project_root_path
+
 
 
 class g160Struct(Structure):
@@ -28,7 +28,7 @@ def cal_g160(cleanFile,inFile,outFile,inOffset,outOffset,maxComNLevel=c_double(-
     :return:
     """
     g160 = g160Struct()
-    mydll = ctypes.windll.LoadLibrary(project_root_path() + 'algorithmLib/G160/g160.dll')
+    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/g160.dll')
     cleFile = c_char_p(bytes(cleanFile.encode('utf-8')))#create_unicode_buffer(cleanFile.encode('utf-8'), len(cleanFile))
     inputFile = c_char_p(bytes(inFile.encode('utf-8')))#create_unicode_buffer(inFile.encode('utf-8'), len(inFile))
     outputFile = c_char_p(bytes(outFile.encode('utf-8')))#create_unicode_buffer(outFile.encode('utf-8'), len(outFile))
