@@ -1,7 +1,7 @@
 
 import ctypes
+import sys
 from ctypes import *
-from algorithmLib.Function import project_root_path
 from algorithmLib.formatConvert.wav_pcm import get_data_array
 
 def resample(infile,target_amplerate):
@@ -9,7 +9,7 @@ def resample(infile,target_amplerate):
     if fs == target_amplerate:
         return infile
     #uint64_t Resample_s16(const int16_t *input, int16_t *output, int inSampleRate, int outSampleRate, uint64_t inputSize,uint32_t channels)
-    mydll = ctypes.windll.LoadLibrary(project_root_path() + 'algorithmLib/resample/resampler.dll')
+    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/resampler.dll')
     outfile = infile[:-4] +'_' +str(target_amplerate) + '.wav'
     infile_ref = c_char_p(bytes(infile.encode('utf-8')))
     outfile_ref = c_char_p(bytes(outfile.encode('utf-8')))
